pub struct DonationPermitDerivedKeyPair { /* private fields */ }Expand description
A key pair used to issue and verify donation permits for a particular expiration.
These are intended to be cheaply cached; the redeeming server only needs the derived key pair, never the root secret.
Implementations
Sourceimpl DonationPermitDerivedKeyPair
impl DonationPermitDerivedKeyPair
Sourcepub fn for_expiration(
expiration: Timestamp,
root: impl AsRef<ServerRootKeyPair>,
) -> Self
pub fn for_expiration( expiration: Timestamp, root: impl AsRef<ServerRootKeyPair>, ) -> Self
Derives the appropriate key pair for the given expiration.
Sourcepub fn expiration(&self) -> Timestamp
pub fn expiration(&self) -> Timestamp
The expiration this key pair was derived for.